[openfabrics-ewg] [PATCH ofed-1.2 alpha rel] IB/iSER: fix iSER name in scripts

Erez Zilber erezz at voltaire.com
Tue Feb 6 02:17:47 PST 2007


Vlad,

The following patch fixes iSER name whenever not written correctly.

--- build_env.sh.orig	2007-02-06 12:10:33.000000000 +0200
+++ build_env.sh	2007-02-06 12:11:37.000000000 +0200
@@ -142,7 +142,7 @@
 
 case ${K_VER} in
     2.6.16.*-*-*)
     # Currently ISER is supported only on SLES10
     IB_KERNEL_PACKAGES="$IB_KERNEL_PACKAGES ib_iser"
     ;;
     2.6.5-7.*)
@@ -169,7 +169,7 @@
     IB_BASIC_PACKAGES="$IB_BASIC_PACKAGES libehca libehca-devel"
 fi
 
 # Add open-iscsi package only if ISER can be installed
 if (echo -n ${IB_KERNEL_PACKAGES} | grep -w "ib_iser" > $NULL); then
     IB_BASIC_PACKAGES="${IB_BASIC_PACKAGES} open_iscsi"
 fi
@@ -1603,7 +1603,7 @@
                             OFA_PACKAGES=$(echo "$OFA_PACKAGES kernel-ib" | tr -s ' ' '\n' | sort -n | uniq)
                     ;;
                     ib_iser)
                         # Currently ISER is supported only on SLES10 RC1
                         # 2.6.[1-9][6-9]*)
                         case ${K_VER} in
                         2.6.16.*-*-*)
@@ -1612,7 +1612,7 @@
                         ;;
                         *)
                             if [ "$prog" == "build.sh" ]; then
-                                warn_echo ISER is not supported by this kernel
+                                warn_echo iSER is not supported by this kernel
                             fi
                         ;;
                         esac
@@ -1820,7 +1820,7 @@
                         esac
                     ;;
                     open_iscsi)
                         # Add open-iscsi package only if ISER can be installed
                         if (echo -n ${SELECTED_PACKAGES} | grep -w "ib_iser" > $NULL); then
                             EXTRA_PACKAGES=$(echo "$EXTRA_PACKAGES open-iscsi" | tr -s ' ' '\n' | sort -rn | uniq)
                         fi
@@ -142,7 +142,7 @@
 case ${K_VER} in
     2.6.16.*-*-*)
-    # Currently ISER is supported only on SLES10
+    # Currently iSER is supported only on SLES10
     IB_KERNEL_PACKAGES="$IB_KERNEL_PACKAGES ib_iser"
     ;;
@@ -169,7 +169,7 @@
 fi
 
-# Add open-iscsi package only if ISER can be installed
+# Add open-iscsi package only if iSER can be installed
 if (echo -n ${IB_KERNEL_PACKAGES} | grep -w "ib_iser" > $NULL); then
     IB_BASIC_PACKAGES="${IB_BASIC_PACKAGES} open_iscsi"
@@ -1603,7 +1603,7 @@
                     ;;
                     ib_iser)
-                        # Currently ISER is supported only on SLES10 RC1
+                        # Currently iSER is supported only on SLES10 RC1
                         # 2.6.[1-9][6-9]*)
                         case ${K_VER} in
@@ -1820,7 +1820,7 @@
                     ;;
                     open_iscsi)
-                        # Add open-iscsi package only if ISER can be installed
+                        # Add open-iscsi package only if iSER can be installed
                         if (echo -n ${SELECTED_PACKAGES} | grep -w "ib_iser" > $NULL); then
                             EXTRA_PACKAGES=$(echo "$EXTRA_PACKAGES open-iscsi" | tr -s ' ' '\n' | sort -rn | uniq)
-- 
____________________________________________________________

Erez Zilber   |  972-9-971-7689

Software Engineer, Storage Team

Voltaire – _The Grid Backbone_

 __

 www.voltaire.com <http://www.voltaire.com/>

<mailto:g at voltaire.com>

  






More information about the ewg mailing list